# TRG

A terminal game

## Setup

Just make a venv by running:

```sh
python -m venv venv
```

Then, install the dependencies:

```sh
pip install -r requirements.txt
```

And finally run the program by doing:

```sh
python -m trg
```

**Note**: Substitute `python` and `pip` with whatever your python and pip are called.
